#
# spec file for package gap-io
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gap-io
Version:        4.9.1
Release:        2.1
Summary:        GAP: Bindings for low level C library IO
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://gap-packages.github.io/io/
#Git-Clone:     https://github.com/gap-packages/io
Source:       	https://github.com/gap-packages/io/releases/download/v%version/io-%version.tar.bz2
BuildRequires:  fdupes
BuildRequires:  gap-devel >= 4.12
BuildRequires:  gap-rpm-devel
BuildRequires:  gmp-devel
Requires:       gap-core >= 4.12

%description
The IO package provides bindings for GAP to the lower levels of
Input/Output functionality in the C library.

%prep
%autosetup -n io-%version

%build
%configure --with-gaproot="%gapdir"
%make_build

%install
%gappkg_simple_install
cd "%buildroot/$fmoddir/"
rm -Rf aclocal* autom4* cnf config* m4 gen src
find . -type f -name "*.la" -print -delete
%fdupes %buildroot/%_prefix

%files -f %name.files

%changelog
* Thu Feb 27 2025 Jan Engelhardt <jengelh@inai.de>
- Make specfile conform to POSIX sh
* Tue Nov 19 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.9.1
  * Switch tests to use a different HTTP provider
* Thu Sep  5 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.9
  * Use IsKernelExtensionAvailable and LoadKernelExtension
* Wed Jul 31 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.8.
  * Check arguments to IO_gmtime and IO_localtime
* Tue Nov 21 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.8.2
  * Properly close all open files on exit
* Sat Feb 11 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.8.1
  * Build system updates only
* Sat Nov 19 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.8
  * Add IO_CallWithTimeout, remove CheckForUpdates
  * Add IO_realpath, add IO_getenv, IO_setenv, IO_unsetenv
  * Fix unpickling of permutation groups with no generators
  * Make IO_stat/IO_lstat/IO_fstat compatible with large files
* Wed Nov 14 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 4.5.4
  * Add exit status to IO_WaitPid
  * Make IO usable in the HPC-GAP threads
  * Replace the deprecated `Elements` in examples by `AsSet`
  * Add IO_getcwd to query the current working directory
  * Fix ChangeDirectoryCurrent when used with relative paths
    (it used to set GAPInfo.DirectoryCurrent to an invalid value)
* Sat Feb  3 2018 jengelh@inai.de
- Update to new upstream release 4.5.1
  * Fix a bug which could break usage IO_mkstemp or IO_mkdtemp in
    a loaded GAP workspace.
* Sun Dec 24 2017 jengelh@inai.de
- Update to new upstream release 4.5.0
  * Add support for (un)pickling ranges and character tables
  * Add automatic call to InstallSIGCHLDHandler() when IO_Fork is
    used directly or indirectly. As a consequence, code directly
    calling IO_fork must now always call IO_WaitPid or the new
    IO_IgnorePid
  * Remove undocumented function IO_MasterPointerNumber
* Sun Jun 19 2016 jengelh@inai.de
- Update to new upstream release 4.4.6
  * Remove support for (un)pickling SuPeRfail
  * Add wrappers for mkstemp and mkdtemp
* Fri Mar 11 2016 jengelh@inai.de
- Update to new upstream release 4.4.5
  * Change IO_PipeThroughWithError to also return the exit status of
  the child process
  * Don't wait for child processes to exit on GAP exit
* Fri Dec 12 2014 jengelh@inai.de
- Update to new upstream release 4.4.4
  * Fix a bug in the IO_Write code, which for example could cause
  IO_WriteLine to fail for certain long string
  * Fix problem with IO_Pickling some very large objects
  * Add pickle support for transformations and partial permutations
  * Try to ensure files are flushed on exit, even if they are
  not explicitly closed.
  * Ensure file buffers are flushed before GAP closes, to
  avoid data loss when files are not closed before exiting.
  * Add = and < methods for IsFile objects
* Wed Jun 18 2014 jengelh@inai.de
- Update to new upstream release 4.3.1
  * Pickling/Unpickling of Floats
- Remove io-install.diff (no longer needed)
* Fri May 10 2013 jengelh@inai.de
- Split io (version 4.2) off the gap RPM package
